@@ -1,8 +1,8 @@
 import django_filters
 from django.db.models import Q
 
-from utilities.filters import NameSlugSearchFilterSet
-
+from utilities.filters import NameSlugSearchFilterSet, TreeNodeMultipleChoiceFilter
+from tenancy.models import Tenant
 from .models import Supervisor
 
 
@@ -17,6 +17,8 @@ class SupervisorFilter(NameSlugSearchFilterSet):
         fields = [
             'status',
             'email',
+            'phone',
+            'tenant',
             'comments',
         ]
 
@@ -33,4 +35,4 @@ class SupervisorFilter(NameSlugSearchFilterSet):
             | Q(phone__icontains=value)
         )
 
-        return queryset.filter(qs_filter)
\ No newline at end of file
+        return queryset.filter(qs_filter)
