@@ -19,7 +19,7 @@ menu_items = (
     ),
     PluginMenuItem(
         link='plugins:netbox_supervisor_plugin:supervisor_tenant_list',
-        link_text='Связи',
+        link_text='Дополнительные связи',
         permissions=['netbox_supervisor_plugin.view_supervisortenant'],
         buttons=(
             PluginMenuButton(
