@@ -9,7 +9,12 @@ class SupervisorTable(BaseTable):
     pk = ToggleColumn()
     sid = tables.LinkColumn(
         viewname='plugins:netbox_supervisor_plugin:supervisor',
-        args=[Accessor('sid')]
+        args=[Accessor('id')]
+    )
+
+    tenant = tables.LinkColumn(
+        viewname='tenancy:tenant',
+        args=[Accessor('tenant.slug')]
     )
 
     class Meta(BaseTable.Meta):
@@ -20,6 +25,7 @@ class SupervisorTable(BaseTable):
             'name',
             'email',
             'phone',
+            'tenant',
             'status',
             'comments',
             'is_active',
@@ -30,7 +36,7 @@ class SupervisorTenantTable(BaseTable):
     pk = ToggleColumn()
     supervisor = tables.LinkColumn(
         viewname='plugins:netbox_supervisor_plugin:supervisor',
-        args=[Accessor('supervisor.sid')]
+        args=[Accessor('supervisor.id')]
     )
     tenant = tables.LinkColumn(
         viewname='tenancy:tenant',
