@@ -1,4 +1,3 @@
-from ipam.models import VLAN
 from tenancy.models import Tenant
 from extras.plugins import PluginTemplateExtension
 
@@ -13,11 +12,17 @@ class SupervisorCount(PluginTemplateExtension):
         m = {}
         # Filter Tenants by tenant.
         tenants = Tenant.objects.filter(name=self.context['object'])
+        obj = self.context['object']
         for t in tenants:
             # If a Tenant is presented, map back to its Supervisor to prevent duplicates.
             if SupervisorTenant.objects.filter(tenant=t).count() == 1:
                 stenant = SupervisorTenant.objects.get(tenant=t)
-                m[stenant.supervisor.sid] = stenant.tenant.id
+                m[stenant.supervisor.id] = stenant.tenant.id
+
+            elif SupervisorTenant.objects.filter(tenant=t).count() > 1:
+                stenants = [st.supervisor.id for st in SupervisorTenant.objects.filter(tenant=t)]
+                ttenants = [st.tenant.id for st in SupervisorTenant.objects.filter(tenant=t)]
+                m = dict(zip(stenants, ttenants))
 
         return self.render('netbox_supervisor_plugin/supervisor_tenant.html', extra_context={
             'count': len(m),
